@@ -2,11 +2,6 @@ from __future__ import print_function
 import github_token
 import getpass
 
-try:
-    input = raw_input
-except NameError:
-    pass
-
 
 def main():
     user = input("Username: ")
@@ -15,9 +10,8 @@ def main():
     token_factory = github_token.TokenFactory(user, password, app_name,
                                               github_token.ALL_SCOPES)
 
-    print(token_factory(
-        tfa_token_callback=lambda: input("TFA Token: ")
-    ))
+    print(token_factory())
+
 
 if __name__ == '__main__':  # pragma: no cover
     exit(main())
